@@ -1,6 +1,7 @@
 import airflow.utils.operator_helpers
 
 from dbnd._core.current import try_get_current_task_run
+from dbnd._core.utils.uid_utils import get_airflow_instance_uid
 from dbnd_airflow.tracking.dbnd_airflow_conf import extend_airflow_ctx_with_dbnd_tracking_info
 
 
@@ -15,5 +16,5 @@ def context_to_airflow_vars(context, in_env_var_format=False):
             params = extend_airflow_ctx_with_dbnd_tracking_info(task_run, params)
 
     try_number = str(context['task_instance'].try_number)
-    params.update({"AIRFLOW_CTX_TRY_NUMBER": try_number})
+    params.update({"AIRFLOW_CTX_TRY_NUMBER": try_number, "AIRFLOW_CTX_UID": get_airflow_instance_uid()})
     return params
